summaryrefslogtreecommitdiffstats
path: root/app/l10n_util.h
diff options
context:
space:
mode:
authorkuan@chromium.org <kuan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-04-02 15:53:44 +0000
committerkuan@chromium.org <kuan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-04-02 15:53:44 +0000
commitf7eb4703666f6e8776ef084e6b60e19616edf7a4 (patch)
tree4f89249b66997767ac2aed0d6595a153b32f6ec7 /app/l10n_util.h
parent931fae8fbb1766629f2d82d772c7f612b440c4b2 (diff)
downloadchromium_src-f7eb4703666f6e8776ef084e6b60e19616edf7a4.zip
chromium_src-f7eb4703666f6e8776ef084e6b60e19616edf7a4.tar.gz
chromium_src-f7eb4703666f6e8776ef084e6b60e19616edf7a4.tar.bz2
translate infobar: sort languages in menus by application locale
- provide string16 sorting methods (there were only std::wstring sorting methods before) - problem is fixed on win, mac, linux and chromeos BUG=39850 TEST=verify per bug report. Review URL: http://codereview.chromium.org/1542009 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@43484 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'app/l10n_util.h')
-rw-r--r--app/l10n_util.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/app/l10n_util.h b/app/l10n_util.h
index c176f73f..e0100c0 100644
--- a/app/l10n_util.h
+++ b/app/l10n_util.h
@@ -174,11 +174,14 @@ string16 ToLower(const string16& string);
// Returns the upper case equivalent of string.
string16 ToUpper(const string16& string);
// In place sorting of strings using collation rules for |locale|.
// TODO(port): this should take string16.
void SortStrings(const std::string& locale,
std::vector<std::wstring>* strings);
+// In place sorting of string16 strings using collation rules for |locale|.
+void SortStrings16(const std::string& locale,
+ std::vector<string16>* strings);
+
// Returns a vector of available locale codes. E.g., a vector containing
// en-US, es, fr, fi, pt-PT, pt-BR, etc.
const std::vector<std::string>& GetAvailableLocales();
@@ -174,11 +174,14 @@ string16 ToLower(const string16& string);
// Returns the upper case equivalent of string.
string16 ToUpper(const string16& string);
-// In place sorting of strings using collation rules for |locale|.
-// TODO(port): this should take string16.
+// In place sorting of std::wstring strings using collation rules for |locale|.
void SortStrings(const std::string& locale,
std::vector<std::wstring>* strings);